pub struct Identity { /* private fields */ }Expand description
Long-term identity. Holds the signing key only on the originating device.
Implementations
Sourceimpl Identity
impl Identity
pub fn generate() -> Self
pub fn user_id(&self) -> &UserId
pub fn public_key(&self) -> VerifyingKey
Sourcepub fn sign_device_binding(&self, device_id: &[u8]) -> Vec<u8> ⓘ
pub fn sign_device_binding(&self, device_id: &[u8]) -> Vec<u8> ⓘ
Sign a (user_id || device_id) binding to issue a device credential.
pub fn verify_device_binding( user_pk: &VerifyingKey, user_id: &UserId, device_id: &[u8], sig: &[u8], ) -> Result<()>
Sourcepub fn export(&self) -> Zeroizing<Vec<u8>>
pub fn export(&self) -> Zeroizing<Vec<u8>>
Export the identity for backup. The returned bytes contain the secret seed and must be treated as such by the caller.
pub fn import(bytes: &[u8]) -> Result<Self>