ping-openmls-sdk-core 0.0.1

Platform-agnostic OpenMLS-based messaging engine
docs.rs failed to build ping-openmls-sdk-core-0.0.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: ping-openmls-sdk-core-0.6.3

Platform-agnostic core for the Ping messaging SDK.

This crate owns OpenMLS state machines and exposes a transport-/storage-agnostic API. Native and WASM bindings are thin wrappers around [MessagingClient].